==> v1.0.0.tar.gz: litexiv/INSTALL.md <==
# Installation

We have guides for installing LiteXiv on your [Nginx](#nginx) or [Apache](#apache) server. <!-- You can also [test it without installation](#testing-without-installation). -->

The following guides are based on Debian-based systems. Choose appropriate commands and packages for your own distro. (PHP >= 5.3 is required.)

## Nginx

1. Install `nginx`, `php` and `php-fpm` if you haven't:
	```bash
	apt install nginx php php-fpm
	```
2. Clone and configure LiteXiv:
	```bash
	cd /var/www
	git clone https://codeberg.org/Peaksol/LiteXiv.git
	nano LiteXiv/include/config.php
	```
3. Add the site to nginx (adjust the configuration as needed):
	```bash
	nano /etc/nginx/sites-enabled/litexiv
	```
	```nginx
	server {
		listen 8080;
		root /var/www/LiteXiv;
		index index.php;

		location ^~ /include/ {
			deny all;
			return 403;
		}

		location ~ \.php$ {
			include snippets/fastcgi-php.conf;
			fastcgi_pass unix:/run/php/php-fpm.sock;
		}

		location / {
			rewrite ^/en/(.*)$ /$1 permanent;
			rewrite ^/(.+)/(.+)$ /$1/index.php?id=$2 last;
		}
	}
	```
4. Restart nginx and php-fpm. The server should be up at configured address.

## Apache

1. Install `apache2`, `php` and `libapache2-mod-php` if you haven't:
	```bash
	apt install apache2 php libapache2-mod-php
	```
2. Clone and configure LiteXiv:
	```bash
	cd /var/www
	git clone https://codeberg.org/Peaksol/LiteXiv.git
	nano LiteXiv/include/config.php
	```
3. Add the site to apache2 (adjust the configuration as needed):
	```bash
	nano /etc/nginx/sites-enabled/litexiv.conf
	```
	```apache
	Listen 8080

	<VirtualHost *:8080>
		ServerName localhost
		DocumentRoot /var/www/LiteXiv

		<Directory /var/www/LiteXiv/include>
			Order allow,deny
			Deny from all
		</directory>

		<Directory /var/www/LiteXiv>
			Require all granted
			RewriteEngine On
			RewriteBase /
			RewriteRule ^en/(.*)$ $1 [QSA,R=301,L]
			RewriteCond %{REQUEST_FILENAME} !-f
			RewriteRule ^(.+)/(.+)$ $1/index.php?id=$2 [QSA,L]
		</Directory>
	</VirtualHost>
	```
4. Restart apache2. The server should be up at configured address.

## Other server software

Installing for other server software (Caddy, Lighttpd, etc.) should be easy. While we don't have guides for them, the process should be as simple as configuring PHP to work with the server and adding some URI rules (rewriting `/foo/?id=bar` as `/foo/bar` and denying access to `/include`).

<!--

## Testing without installation

You can test the application without installing it, using PHP's built-in web server:

```bash
php -S 0.0.0.0:8080
```

Since the built-in server is single-threaded, loading can be slow. If you are using PHP >= 7.4.0, you can configure the server to fork multiple workers:

```bash
PHP_CLI_SERVER_WORKERS=4 php -S 0.0.0.0:8080
```

**Note that the built-in server is for testing purpose only; do not use it for production!**

-->

==> v1.1.0.tar.gz: litexiv/INSTALL.md <==
# Installation

We have guides for installing LiteXiv on your [Nginx](#nginx) or [Apache](#apache) server. <!-- You can also [test it without installation](#testing-without-installation). -->

The following guides are based on Debian-based systems. Choose appropriate commands and packages for your own distro. (PHP >= 5.3 is required.)

## Nginx

1. Install `nginx`, `php` and `php-fpm` if you haven't:
	```bash
	apt install nginx php php-fpm
	```
2. Clone and configure LiteXiv:
	```bash
	cd /var/www
	git clone https://codeberg.org/Peaksol/LiteXiv.git
	nano LiteXiv/include/config.php
	```
3. Add the site to nginx (adjust the configuration as needed):
	```bash
	nano /etc/nginx/sites-enabled/litexiv
	```
	```nginx
	server {
		listen 8080;
		root /var/www/LiteXiv;
		index index.php;

		location ^~ /include/ {
			deny all;
			return 403;
		}

		location ~ \.php$ {
			include snippets/fastcgi-php.conf;
			fastcgi_pass unix:/run/php/php-fpm.sock;
		}

		location / {
			rewrite ^/en/(.*)$ /$1 permanent;
			rewrite ^/(artworks|users|tags)/(.*?)(/(.*))?$ /$1/index.php?id=$2&category=$4 last;
			rewrite ^/proxy/(.*)$ /proxy.php?dest=$1 last;
		}
	}
	```
4. Restart nginx and php-fpm. The server should be up at configured address.

## Apache

1. Install `apache2`, `php` and `libapache2-mod-php` if you haven't:
	```bash
	apt install apache2 php libapache2-mod-php
	```
2. Clone and configure LiteXiv:
	```bash
	cd /var/www
	git clone https://codeberg.org/Peaksol/LiteXiv.git
	nano LiteXiv/include/config.php
	```
3. Add the site to apache2 (adjust the configuration as needed):
	```bash
	nano /etc/nginx/sites-enabled/litexiv.conf
	```
	```apache
	Listen 8080

	<VirtualHost *:8080>
		ServerName localhost
		DocumentRoot /var/www/LiteXiv

		<Directory /var/www/LiteXiv/include>
			Order allow,deny
			Deny from all
		</directory>

		<Directory /var/www/LiteXiv>
			Require all granted
			RewriteEngine On
			RewriteBase /
			RewriteRule ^en/(.*)$ $1 [QSA,R=301,L]
			RewriteCond %{REQUEST_FILENAME} !-f
			RewriteRule ^(artworks|users|tags)/(.*?)(/(.*))?$ $1/index.php?id=$2&category=$4 [QSA,L]
			RewriteRule ^proxy/(.*)$ proxy.php?dest=$1 [QSA,L]
		</Directory>
	</VirtualHost>
	```
4. Restart apache2. The server should be up at configured address.

## Other server software

Installing for other server software (Caddy, Lighttpd, etc.) should be easy. While we don't have guides for them, the process should be as simple as configuring PHP to work with the server and adding some URI rules (see configurations for nginx and apache above).

<!--

## Testing without installation

You can test the application without installing it, using PHP's built-in web server:

```bash
php -S 0.0.0.0:8080
```

Since the built-in server is single-threaded, loading can be slow. If you are using PHP >= 7.4.0, you can configure the server to fork multiple workers:

```bash
PHP_CLI_SERVER_WORKERS=4 php -S 0.0.0.0:8080
```

**Note that the built-in server is for testing purpose only; do not use it for production!**

-->
